@@ -2,7 +2,7 @@
 import numpy
 import numpoly
 
-from .common import implements
+from ..dispatch import implements
 
 @implements(numpy.expand_dims)
 def expand_dims(a, axis):
